# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponsePointOfSaleInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'terminal_id': 'str',
        'entry_mode': 'str',
        'terminal_capability': 'int',
        'emv': 'Ptsv2paymentsidreversalsPointOfSaleInformationEmv'
    }

    attribute_map = {
        'terminal_id': 'terminalId',
        'entry_mode': 'entryMode',
        'terminal_capability': 'terminalCapability',
        'emv': 'emv'
    }

    def __init__(self, terminal_id=None, entry_mode=None, terminal_capability=None, emv=None):
        """
        TssV2TransactionsGet200ResponsePointOfSaleInformation - a model defined in Swagger
        """

        self._terminal_id = None
        self._entry_mode = None
        self._terminal_capability = None
        self._emv = None

        if terminal_id is not None:
          self.terminal_id = terminal_id
        if entry_mode is not None:
          self.entry_mode = entry_mode
        if terminal_capability is not None:
          self.terminal_capability = terminal_capability
        if emv is not None:
          self.emv = emv

    @property
    def terminal_id(self):
        """
        Gets the terminal_id of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :return: The terminal_id of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :rtype: str
        """
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, terminal_id):
        """
        Sets the terminal_id of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :param terminal_id: The terminal_id of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :type: str
        """
        if terminal_id is not None and len(terminal_id) > 8:
            raise ValueError("Invalid value for `terminal_id`, length must be less than or equal to `8`")

        self._terminal_id = terminal_id

    @property
    def entry_mode(self):
        """
        Gets the entry_mode of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        Method of entering payment card information into the POS terminal. Possible values:   - `contact`: Read from direct contact with chip card.  - `contactless`: Read from a contactless interface using chip data.  - `keyed`: Manually keyed into POS terminal. This value is not supported on OmniPay Direct.  - `msd`: Read from a contactless interface using magnetic stripe data (MSD). This value is not supported on OmniPay Direct.  - `swiped`: Read from credit card magnetic stripe.  The `contact`, `contactless`, and `msd` values are supported only for EMV transactions.  #### Used by **Authorization** Required field.  #### Card Present Card present information about EMV applies only to credit card processing and PIN debit processing. All other card present information applies only to credit card processing.  #### PIN debit Required for a PIN debit purchase and a PIN debit credit request. 

        :return: The entry_mode of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :rtype: str
        """
        return self._entry_mode

    @entry_mode.setter
    def entry_mode(self, entry_mode):
        """
        Sets the entry_mode of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        Method of entering payment card information into the POS terminal. Possible values:   - `contact`: Read from direct contact with chip card.  - `contactless`: Read from a contactless interface using chip data.  - `keyed`: Manually keyed into POS terminal. This value is not supported on OmniPay Direct.  - `msd`: Read from a contactless interface using magnetic stripe data (MSD). This value is not supported on OmniPay Direct.  - `swiped`: Read from credit card magnetic stripe.  The `contact`, `contactless`, and `msd` values are supported only for EMV transactions.  #### Used by **Authorization** Required field.  #### Card Present Card present information about EMV applies only to credit card processing and PIN debit processing. All other card present information applies only to credit card processing.  #### PIN debit Required for a PIN debit purchase and a PIN debit credit request. 

        :param entry_mode: The entry_mode of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :type: str
        """
        if entry_mode is not None and len(entry_mode) > 11:
            raise ValueError("Invalid value for `entry_mode`, length must be less than or equal to `11`")

        self._entry_mode = entry_mode

    @property
    def terminal_capability(self):
        """
        Gets the terminal_capability of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        POS terminal’s capability. Possible values:   - `1`: Terminal has a magnetic stripe reader only.  - `2`: Terminal has a magnetic stripe reader and manual entry capability.  - `3`: Terminal has manual entry capability only.  - `4`: Terminal can read chip cards.  - `5`: Terminal can read contactless chip cards; cannot use contact to read chip cards.  For an EMV transaction, the value of this field must be `4` or `5`.  #### PIN debit Required for PIN debit purchase and PIN debit credit request.  #### Used by **Authorization** Required for the following processors: - American Express Direct - Chase Paymentech Solutions - Credit Mutuel-CIC - FDC Nashville Global - FDMS Nashville - OmniPay Direct - SIX - Worldpay VAP  Optional for the following processors: - CyberSource through VisaNet - GPN - GPX - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions 

        :return: The terminal_capability of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :rtype: int
        """
        return self._terminal_capability

    @terminal_capability.setter
    def terminal_capability(self, terminal_capability):
        """
        Sets the terminal_capability of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        POS terminal’s capability. Possible values:   - `1`: Terminal has a magnetic stripe reader only.  - `2`: Terminal has a magnetic stripe reader and manual entry capability.  - `3`: Terminal has manual entry capability only.  - `4`: Terminal can read chip cards.  - `5`: Terminal can read contactless chip cards; cannot use contact to read chip cards.  For an EMV transaction, the value of this field must be `4` or `5`.  #### PIN debit Required for PIN debit purchase and PIN debit credit request.  #### Used by **Authorization** Required for the following processors: - American Express Direct - Chase Paymentech Solutions - Credit Mutuel-CIC - FDC Nashville Global - FDMS Nashville - OmniPay Direct - SIX - Worldpay VAP  Optional for the following processors: - CyberSource through VisaNet - GPN - GPX - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions 

        :param terminal_capability: The terminal_capability of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :type: int
        """
        if terminal_capability is not None and terminal_capability > 5:
            raise ValueError("Invalid value for `terminal_capability`, must be a value less than or equal to `5`")
        if terminal_capability is not None and terminal_capability < 1:
            raise ValueError("Invalid value for `terminal_capability`, must be a value greater than or equal to `1`")

        self._terminal_capability = terminal_capability

    @property
    def emv(self):
        """
        Gets the emv of this TssV2TransactionsGet200ResponsePointOfSaleInformation.

        :return: The emv of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :rtype: Ptsv2paymentsidreversalsPointOfSaleInformationEmv
        """
        return self._emv

    @emv.setter
    def emv(self, emv):
        """
        Sets the emv of this TssV2TransactionsGet200ResponsePointOfSaleInformation.

        :param emv: The emv of this TssV2TransactionsGet200ResponsePointOfSaleInformation.
        :type: Ptsv2paymentsidreversalsPointOfSaleInformationEmv
        """

        self._emv = emv

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponsePointOfSaleInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'terminal_id': 'str',
        'terminal_serial_number': 'str',
        'device_id': 'str',
        'partner': 'TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner'
    }

    attribute_map = {
        'terminal_id': 'terminalId',
        'terminal_serial_number': 'terminalSerialNumber',
        'device_id': 'deviceId',
        'partner': 'partner'
    }

    def __init__(self, terminal_id=None, terminal_serial_number=None, device_id=None, partner=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation - a model defined in Swagger
        """

        self._terminal_id = None
        self._terminal_serial_number = None
        self._device_id = None
        self._partner = None

        if terminal_id is not None:
          self.terminal_id = terminal_id
        if terminal_serial_number is not None:
          self.terminal_serial_number = terminal_serial_number
        if device_id is not None:
          self.device_id = device_id
        if partner is not None:
          self.partner = partner

    @property
    def terminal_id(self):
        """
        Gets the terminal_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :return: The terminal_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :rtype: str
        """
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, terminal_id):
        """
        Sets the terminal_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :param terminal_id: The terminal_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :type: str
        """
        if terminal_id is not None and len(terminal_id) > 8:
            raise ValueError("Invalid value for `terminal_id`, length must be less than or equal to `8`")

        self._terminal_id = terminal_id

    @property
    def terminal_serial_number(self):
        """
        Gets the terminal_serial_number of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Terminal serial number assigned by the hardware manufacturer. This value is provided by the client software that is installed on the POS terminal.  This value is not forwarded to the processor. Instead, the value is forwarded to the reporting functionality.  #### Used by **Authorization and Credit** Optional. This field is supported only by client software that is installed on your POS terminals for the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :return: The terminal_serial_number of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :rtype: str
        """
        return self._terminal_serial_number

    @terminal_serial_number.setter
    def terminal_serial_number(self, terminal_serial_number):
        """
        Sets the terminal_serial_number of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Terminal serial number assigned by the hardware manufacturer. This value is provided by the client software that is installed on the POS terminal.  This value is not forwarded to the processor. Instead, the value is forwarded to the reporting functionality.  #### Used by **Authorization and Credit** Optional. This field is supported only by client software that is installed on your POS terminals for the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :param terminal_serial_number: The terminal_serial_number of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :type: str
        """
        if terminal_serial_number is not None and len(terminal_serial_number) > 32:
            raise ValueError("Invalid value for `terminal_serial_number`, length must be less than or equal to `32`")

        self._terminal_serial_number = terminal_serial_number

    @property
    def device_id(self):
        """
        Gets the device_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Value created by the client software that uniquely identifies the POS device. CyberSource does not forward this value to the processor. Instead, the value is forwarded to the CyberSource reporting functionality.  This field is supported only for authorizations and credits on these processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX  Optional field. String (32) 

        :return: The device_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """
        Sets the device_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        Value created by the client software that uniquely identifies the POS device. CyberSource does not forward this value to the processor. Instead, the value is forwarded to the CyberSource reporting functionality.  This field is supported only for authorizations and credits on these processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX  Optional field. String (32) 

        :param device_id: The device_id of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :type: str
        """

        self._device_id = device_id

    @property
    def partner(self):
        """
        Gets the partner of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.

        :return: The partner of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner
        """
        return self._partner

    @partner.setter
    def partner(self, partner):
        """
        Sets the partner of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.

        :param partner: The partner of this TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation.
        :type: TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner
        """

        self._partner = partner

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_type': 'str',
        'verbal_auth_code': 'str',
        'verbal_auth_transaction_id': 'str'
    }

    attribute_map = {
        'auth_type': 'authType',
        'verbal_auth_code': 'verbalAuthCode',
        'verbal_auth_transaction_id': 'verbalAuthTransactionId'
    }

    def __init__(self, auth_type=None, verbal_auth_code=None, verbal_auth_transaction_id=None):
        """
        Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions - a model defined in Swagger
        """

        self._auth_type = None
        self._verbal_auth_code = None
        self._verbal_auth_transaction_id = None

        if auth_type is not None:
          self.auth_type = auth_type
        if verbal_auth_code is not None:
          self.verbal_auth_code = verbal_auth_code
        if verbal_auth_transaction_id is not None:
          self.verbal_auth_transaction_id = verbal_auth_transaction_id

    @property
    def auth_type(self):
        """
        Gets the auth_type of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Authorization type. Possible values:   - `AUTOCAPTURE`: automatic capture.  - `STANDARDCAPTURE`: standard capture.  - `VERBAL`: forced capture. Include it in the payment request for a forced capture. Include it in the capture request for a verbal payment.  #### Asia, Middle East, and Africa Gateway; Cielo; Comercio Latino; and CyberSource Latin American Processing Set this field to `AUTOCAPTURE` and include it in a bundled request to indicate that you are requesting an automatic capture. If your account is configured to enable automatic captures, set this field to `STANDARDCAPTURE` and include it in a standard authorization or bundled request to indicate that you are overriding an automatic capture. For more information, see the `auth_type` field description in [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Forced Capture Set this field to `VERBAL` and include it in the authorization request to indicate that you are performing a forced capture; therefore, you receive the authorization code outside the CyberSource system.  #### Verbal Authorization Set this field to `VERBAL` and include it in the capture request to indicate that the request is for a verbal authorization. For more information, see \"Verbal Authorizations\" in [Credit Card Services Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html). 

        :return: The auth_type of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :rtype: str
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """
        Sets the auth_type of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Authorization type. Possible values:   - `AUTOCAPTURE`: automatic capture.  - `STANDARDCAPTURE`: standard capture.  - `VERBAL`: forced capture. Include it in the payment request for a forced capture. Include it in the capture request for a verbal payment.  #### Asia, Middle East, and Africa Gateway; Cielo; Comercio Latino; and CyberSource Latin American Processing Set this field to `AUTOCAPTURE` and include it in a bundled request to indicate that you are requesting an automatic capture. If your account is configured to enable automatic captures, set this field to `STANDARDCAPTURE` and include it in a standard authorization or bundled request to indicate that you are overriding an automatic capture. For more information, see the `auth_type` field description in [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Forced Capture Set this field to `VERBAL` and include it in the authorization request to indicate that you are performing a forced capture; therefore, you receive the authorization code outside the CyberSource system.  #### Verbal Authorization Set this field to `VERBAL` and include it in the capture request to indicate that the request is for a verbal authorization. For more information, see \"Verbal Authorizations\" in [Credit Card Services Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html). 

        :param auth_type: The auth_type of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :type: str
        """
        if auth_type is not None and len(auth_type) > 15:
            raise ValueError("Invalid value for `auth_type`, length must be less than or equal to `15`")

        self._auth_type = auth_type

    @property
    def verbal_auth_code(self):
        """
        Gets the verbal_auth_code of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Authorization code.  #### Forced Capture Use this field to send the authorization code you received from a payment that you authorized outside the CyberSource system.  #### PIN debit Authorization code that is returned by the processor.  Returned by PIN debit purchase.  #### Verbal Authorization Use this field in CAPTURE API to send the verbally received authorization code.  For processor-specific information, see the `auth_code` field description in [Credit Card Services Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html). 

        :return: The verbal_auth_code of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :rtype: str
        """
        return self._verbal_auth_code

    @verbal_auth_code.setter
    def verbal_auth_code(self, verbal_auth_code):
        """
        Sets the verbal_auth_code of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Authorization code.  #### Forced Capture Use this field to send the authorization code you received from a payment that you authorized outside the CyberSource system.  #### PIN debit Authorization code that is returned by the processor.  Returned by PIN debit purchase.  #### Verbal Authorization Use this field in CAPTURE API to send the verbally received authorization code.  For processor-specific information, see the `auth_code` field description in [Credit Card Services Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html). 

        :param verbal_auth_code: The verbal_auth_code of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :type: str
        """
        if verbal_auth_code is not None and len(verbal_auth_code) > 7:
            raise ValueError("Invalid value for `verbal_auth_code`, length must be less than or equal to `7`")

        self._verbal_auth_code = verbal_auth_code

    @property
    def verbal_auth_transaction_id(self):
        """
        Gets the verbal_auth_transaction_id of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Transaction ID (TID).  #### FDMS South This field is required for verbal authorizations and forced captures with the American Express card type to comply with the CAPN requirements: - Forced capture: Obtain the value for this field from the authorization response. - Verbal authorization: You cannot obtain a value for this field so CyberSource uses the default value of `000000000000000` (15 zeros). 

        :return: The verbal_auth_transaction_id of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :rtype: str
        """
        return self._verbal_auth_transaction_id

    @verbal_auth_transaction_id.setter
    def verbal_auth_transaction_id(self, verbal_auth_transaction_id):
        """
        Sets the verbal_auth_transaction_id of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        Transaction ID (TID).  #### FDMS South This field is required for verbal authorizations and forced captures with the American Express card type to comply with the CAPN requirements: - Forced capture: Obtain the value for this field from the authorization response. - Verbal authorization: You cannot obtain a value for this field so CyberSource uses the default value of `000000000000000` (15 zeros). 

        :param verbal_auth_transaction_id: The verbal_auth_transaction_id of this Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions.
        :type: str
        """
        if verbal_auth_transaction_id is not None and len(verbal_auth_transaction_id) > 15:
            raise ValueError("Invalid value for `verbal_auth_transaction_id`, length must be less than or equal to `15`")

        self._verbal_auth_transaction_id = verbal_auth_transaction_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseRiskInformationRules(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'decision': 'str'
    }

    attribute_map = {
        'name': 'name',
        'decision': 'decision'
    }

    def __init__(self, name=None, decision=None):
        """
        PtsV2PaymentsPost201ResponseRiskInformationRules - a model defined in Swagger
        """

        self._name = None
        self._decision = None

        if name is not None:
          self.name = name
        if decision is not None:
          self.decision = decision

    @property
    def name(self):
        """
        Gets the name of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        Description of the rule as it appears in the Profile Editor.

        :return: The name of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        Description of the rule as it appears in the Profile Editor.

        :param name: The name of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        :type: str
        """
        if name is not None and len(name) > 255:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")

        self._name = name

    @property
    def decision(self):
        """
        Gets the decision of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        Summarizes the result for the rule according to the setting that you chose in the Profile Editor. This field can contain one of the following values: - `IGNORE` - `REVIEW` - `REJECT` - `ACCEPT` 

        :return: The decision of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        :rtype: str
        """
        return self._decision

    @decision.setter
    def decision(self, decision):
        """
        Sets the decision of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        Summarizes the result for the rule according to the setting that you chose in the Profile Editor. This field can contain one of the following values: - `IGNORE` - `REVIEW` - `REJECT` - `ACCEPT` 

        :param decision: The decision of this PtsV2PaymentsPost201ResponseRiskInformationRules.
        :type: str
        """
        if decision is not None and len(decision) > 255:
            raise ValueError("Invalid value for `decision`, length must be less than or equal to `255`")

        self._decision = decision

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseRiskInformationRules):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedProcessorInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'processor': 'TssV2TransactionsGet200ResponseProcessorInformationProcessor',
        'approval_code': 'str'
    }

    attribute_map = {
        'processor': 'processor',
        'approval_code': 'approvalCode'
    }

    def __init__(self, processor=None, approval_code=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedProcessorInformation - a model defined in Swagger
        """

        self._processor = None
        self._approval_code = None

        if processor is not None:
          self.processor = processor
        if approval_code is not None:
          self.approval_code = approval_code

    @property
    def processor(self):
        """
        Gets the processor of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.

        :return: The processor of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        :rtype: TssV2TransactionsGet200ResponseProcessorInformationProcessor
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """
        Sets the processor of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.

        :param processor: The processor of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        :type: TssV2TransactionsGet200ResponseProcessorInformationProcessor
        """

        self._processor = processor

    @property
    def approval_code(self):
        """
        Gets the approval_code of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        Authorization code. Returned only when the processor returns this value.  The length of this value depends on your processor.  Returned by authorization service.  #### PIN debit Authorization code that is returned by the processor.  Returned by PIN debit credit.  #### Elavon Encrypted Account Number Program The returned value is OFFLINE.  #### TSYS Acquiring Solutions The returned value for a successful zero amount authorization is 000000. 

        :return: The approval_code of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        :rtype: str
        """
        return self._approval_code

    @approval_code.setter
    def approval_code(self, approval_code):
        """
        Sets the approval_code of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        Authorization code. Returned only when the processor returns this value.  The length of this value depends on your processor.  Returned by authorization service.  #### PIN debit Authorization code that is returned by the processor.  Returned by PIN debit credit.  #### Elavon Encrypted Account Number Program The returned value is OFFLINE.  #### TSYS Acquiring Solutions The returned value for a successful zero amount authorization is 000000. 

        :param approval_code: The approval_code of this TssV2TransactionsPost201ResponseEmbeddedProcessorInformation.
        :type: str
        """

        self._approval_code = approval_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedProcessorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'with_apartment': 'str',
        'without_apartment': 'str'
    }

    attribute_map = {
        'with_apartment': 'withApartment',
        'without_apartment': 'withoutApartment'
    }

    def __init__(self, with_apartment=None, without_apartment=None):
        """
        RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1 - a model defined in Swagger
        """

        self._with_apartment = None
        self._without_apartment = None

        if with_apartment is not None:
          self.with_apartment = with_apartment
        if without_apartment is not None:
          self.without_apartment = without_apartment

    @property
    def with_apartment(self):
        """
        Gets the with_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        First line of the standardized address, including apartment information.

        :return: The with_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        :rtype: str
        """
        return self._with_apartment

    @with_apartment.setter
    def with_apartment(self, with_apartment):
        """
        Sets the with_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        First line of the standardized address, including apartment information.

        :param with_apartment: The with_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        :type: str
        """
        if with_apartment is not None and len(with_apartment) > 255:
            raise ValueError("Invalid value for `with_apartment`, length must be less than or equal to `255`")

        self._with_apartment = with_apartment

    @property
    def without_apartment(self):
        """
        Gets the without_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        First line of the standardized address, without apartment information. Returned for U.S. and Canadian addresses. 

        :return: The without_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        :rtype: str
        """
        return self._without_apartment

    @without_apartment.setter
    def without_apartment(self, without_apartment):
        """
        Sets the without_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        First line of the standardized address, without apartment information. Returned for U.S. and Canadian addresses. 

        :param without_apartment: The without_apartment of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1.
        :type: str
        """
        if without_apartment is not None and len(without_apartment) > 255:
            raise ValueError("Invalid value for `without_apartment`, length must be less than or equal to `255`")

        self._without_apartment = without_apartment

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class AddNegativeListRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_information': 'Riskv1liststypeentriesOrderInformation',
        'payment_information': 'Riskv1liststypeentriesPaymentInformation',
        'client_reference_information': 'Riskv1decisionsClientReferenceInformation',
        'device_information': 'Riskv1liststypeentriesDeviceInformation',
        'risk_information': 'Riskv1liststypeentriesRiskInformation',
        'buyer_information': 'Riskv1liststypeentriesBuyerInformation'
    }

    attribute_map = {
        'order_information': 'orderInformation',
        'payment_information': 'paymentInformation',
        'client_reference_information': 'clientReferenceInformation',
        'device_information': 'deviceInformation',
        'risk_information': 'riskInformation',
        'buyer_information': 'buyerInformation'
    }

    def __init__(self, order_information=None, payment_information=None, client_reference_information=None, device_information=None, risk_information=None, buyer_information=None):
        """
        AddNegativeListRequest - a model defined in Swagger
        """

        self._order_information = None
        self._payment_information = None
        self._client_reference_information = None
        self._device_information = None
        self._risk_information = None
        self._buyer_information = None

        if order_information is not None:
          self.order_information = order_information
        if payment_information is not None:
          self.payment_information = payment_information
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if device_information is not None:
          self.device_information = device_information
        if risk_information is not None:
          self.risk_information = risk_information
        if buyer_information is not None:
          self.buyer_information = buyer_information

    @property
    def order_information(self):
        """
        Gets the order_information of this AddNegativeListRequest.

        :return: The order_information of this AddNegativeListRequest.
        :rtype: Riskv1liststypeentriesOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this AddNegativeListRequest.

        :param order_information: The order_information of this AddNegativeListRequest.
        :type: Riskv1liststypeentriesOrderInformation
        """

        self._order_information = order_information

    @property
    def payment_information(self):
        """
        Gets the payment_information of this AddNegativeListRequest.

        :return: The payment_information of this AddNegativeListRequest.
        :rtype: Riskv1liststypeentriesPaymentInformation
        """
        return self._payment_information

    @payment_information.setter
    def payment_information(self, payment_information):
        """
        Sets the payment_information of this AddNegativeListRequest.

        :param payment_information: The payment_information of this AddNegativeListRequest.
        :type: Riskv1liststypeentriesPaymentInformation
        """

        self._payment_information = payment_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this AddNegativeListRequest.

        :return: The client_reference_information of this AddNegativeListRequest.
        :rtype: Riskv1decisionsClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this AddNegativeListRequest.

        :param client_reference_information: The client_reference_information of this AddNegativeListRequest.
        :type: Riskv1decisionsClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def device_information(self):
        """
        Gets the device_information of this AddNegativeListRequest.

        :return: The device_information of this AddNegativeListRequest.
        :rtype: Riskv1liststypeentriesDeviceInformation
        """
        return self._device_information

    @device_information.setter
    def device_information(self, device_information):
        """
        Sets the device_information of this AddNegativeListRequest.

        :param device_information: The device_information of this AddNegativeListRequest.
        :type: Riskv1liststypeentriesDeviceInformation
        """

        self._device_information = device_information

    @property
    def risk_information(self):
        """
        Gets the risk_information of this AddNegativeListRequest.

        :return: The risk_information of this AddNegativeListRequest.
        :rtype: Riskv1liststypeentriesRiskInformation
        """
        return self._risk_information

    @risk_information.setter
    def risk_information(self, risk_information):
        """
        Sets the risk_information of this AddNegativeListRequest.

        :param risk_information: The risk_information of this AddNegativeListRequest.
        :type: Riskv1liststypeentriesRiskInformation
        """

        self._risk_information = risk_information

    @property
    def buyer_information(self):
        """
        Gets the buyer_information of this AddNegativeListRequest.

        :return: The buyer_information of this AddNegativeListRequest.
        :rtype: Riskv1liststypeentriesBuyerInformation
        """
        return self._buyer_information

    @buyer_information.setter
    def buyer_information(self, buyer_information):
        """
        Sets the buyer_information of this AddNegativeListRequest.

        :param buyer_information: The buyer_information of this AddNegativeListRequest.
        :type: Riskv1liststypeentriesBuyerInformation
        """

        self._buyer_information = buyer_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AddNegativeListRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'amount': 'str',
        'rate': 'str'
    }

    attribute_map = {
        'type': 'type',
        'amount': 'amount',
        'rate': 'rate'
    }

    def __init__(self, type=None, amount=None, rate=None):
        """
        Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails - a model defined in Swagger
        """

        self._type = None
        self._amount = None
        self._rate = None

        if type is not None:
          self.type = type
        if amount is not None:
          self.amount = amount
        if rate is not None:
          self.rate = rate

    @property
    def type(self):
        """
        Gets the type of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Indicates the type of tax data for the _taxDetails_ object.  Possible values:  - `alternate` - `local` - `national` - `vat` - `other`  For processor-specific details, see the `alternate_tax_amount`, `local_tax`, `national_tax` or `vat_tax_amount` field descriptions in [Level II and Level III Processing Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :return: The type of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Indicates the type of tax data for the _taxDetails_ object.  Possible values:  - `alternate` - `local` - `national` - `vat` - `other`  For processor-specific details, see the `alternate_tax_amount`, `local_tax`, `national_tax` or `vat_tax_amount` field descriptions in [Level II and Level III Processing Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :param type: The type of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :type: str
        """

        self._type = type

    @property
    def amount(self):
        """
        Gets the amount of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Indicates the amount of tax based on the `type` field as described in the table below:  | type      | type description | | ------------- |:-------------:| | `alternate` | Total amount of alternate tax for the order. | | `local`     | Sales tax for the order. | | `national`  | National tax for the order. | | `vat`       | Total amount of value added tax (VAT) included in the order. | | `other`     | Other tax. | 

        :return: The amount of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Indicates the amount of tax based on the `type` field as described in the table below:  | type      | type description | | ------------- |:-------------:| | `alternate` | Total amount of alternate tax for the order. | | `local`     | Sales tax for the order. | | `national`  | National tax for the order. | | `vat`       | Total amount of value added tax (VAT) included in the order. | | `other`     | Other tax. | 

        :param amount: The amount of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :type: str
        """
        if amount is not None and len(amount) > 13:
            raise ValueError("Invalid value for `amount`, length must be less than or equal to `13`")

        self._amount = amount

    @property
    def rate(self):
        """
        Gets the rate of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Rate of VAT or other tax for the order.  Example 0.040 (=4%)  Valid range: 0.01 to 0.99 (1% to 99%, with only whole percentage values accepted; values with additional decimal places will be truncated)  For processor-specific details, see the `alternate_tax_amount`, `vat_rate`, `vat_tax_rate`, `local_tax`, `national_tax`, `vat_tax_amount` or `other_tax#_rate` field descriptions in the [Level II and Level III Processing Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :return: The rate of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :rtype: str
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """
        Sets the rate of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        Rate of VAT or other tax for the order.  Example 0.040 (=4%)  Valid range: 0.01 to 0.99 (1% to 99%, with only whole percentage values accepted; values with additional decimal places will be truncated)  For processor-specific details, see the `alternate_tax_amount`, `vat_rate`, `vat_tax_rate`, `local_tax`, `national_tax`, `vat_tax_amount` or `other_tax#_rate` field descriptions in the [Level II and Level III Processing Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :param rate: The rate of this Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails.
        :type: str
        """
        if rate is not None and len(rate) > 6:
            raise ValueError("Invalid value for `rate`, length must be less than or equal to `6`")

        self._rate = rate

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidcapturesAggregatorInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregator_id': 'str',
        'name': 'str',
        'sub_merchant': 'Ptsv2paymentsidcapturesAggregatorInformationSubMerchant'
    }

    attribute_map = {
        'aggregator_id': 'aggregatorId',
        'name': 'name',
        'sub_merchant': 'subMerchant'
    }

    def __init__(self, aggregator_id=None, name=None, sub_merchant=None):
        """
        Ptsv2paymentsidcapturesAggregatorInformation - a model defined in Swagger
        """

        self._aggregator_id = None
        self._name = None
        self._sub_merchant = None

        if aggregator_id is not None:
          self.aggregator_id = aggregator_id
        if name is not None:
          self.name = name
        if sub_merchant is not None:
          self.sub_merchant = sub_merchant

    @property
    def aggregator_id(self):
        """
        Gets the aggregator_id of this Ptsv2paymentsidcapturesAggregatorInformation.
        Value that identifies you as a payment aggregator. Get this value from the processor.  #### CyberSource through VisaNet The value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR6 - Position: 95-105 - Field: MasterCard Payment Facilitator ID  **FDC Compass**\\ This value must consist of uppercase characters.  For processor-specific information, see the `aggregator_id` field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The aggregator_id of this Ptsv2paymentsidcapturesAggregatorInformation.
        :rtype: str
        """
        return self._aggregator_id

    @aggregator_id.setter
    def aggregator_id(self, aggregator_id):
        """
        Sets the aggregator_id of this Ptsv2paymentsidcapturesAggregatorInformation.
        Value that identifies you as a payment aggregator. Get this value from the processor.  #### CyberSource through VisaNet The value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR6 - Position: 95-105 - Field: MasterCard Payment Facilitator ID  **FDC Compass**\\ This value must consist of uppercase characters.  For processor-specific information, see the `aggregator_id` field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param aggregator_id: The aggregator_id of this Ptsv2paymentsidcapturesAggregatorInformation.
        :type: str
        """
        if aggregator_id is not None and len(aggregator_id) > 20:
            raise ValueError("Invalid value for `aggregator_id`, length must be less than or equal to `20`")

        self._aggregator_id = aggregator_id

    @property
    def name(self):
        """
        Gets the name of this Ptsv2paymentsidcapturesAggregatorInformation.
        Your payment aggregator business name.  **American Express Direct**\\ The maximum length of the aggregator name depends on the length of the sub-merchant name. The combined length for both values must not exceed 36 characters.\\  #### CyberSource through VisaNet With American Express, the maximum length of the aggregator name depends on the length of the sub-merchant name. The combined length for both values must not exceed 36 characters. The value for this field does not map to the TC 33 capture file5.  **FDC Compass**\\ This value must consist of uppercase characters.  For processor-specific information, see the aggregator_name field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The name of this Ptsv2paymentsidcapturesAggregatorInformation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2paymentsidcapturesAggregatorInformation.
        Your payment aggregator business name.  **American Express Direct**\\ The maximum length of the aggregator name depends on the length of the sub-merchant name. The combined length for both values must not exceed 36 characters.\\  #### CyberSource through VisaNet With American Express, the maximum length of the aggregator name depends on the length of the sub-merchant name. The combined length for both values must not exceed 36 characters. The value for this field does not map to the TC 33 capture file5.  **FDC Compass**\\ This value must consist of uppercase characters.  For processor-specific information, see the aggregator_name field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param name: The name of this Ptsv2paymentsidcapturesAggregatorInformation.
        :type: str
        """
        if name is not None and len(name) > 37:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `37`")

        self._name = name

    @property
    def sub_merchant(self):
        """
        Gets the sub_merchant of this Ptsv2paymentsidcapturesAggregatorInformation.

        :return: The sub_merchant of this Ptsv2paymentsidcapturesAggregatorInformation.
        :rtype: Ptsv2paymentsidcapturesAggregatorInformationSubMerchant
        """
        return self._sub_merchant

    @sub_merchant.setter
    def sub_merchant(self, sub_merchant):
        """
        Sets the sub_merchant of this Ptsv2paymentsidcapturesAggregatorInformation.

        :param sub_merchant: The sub_merchant of this Ptsv2paymentsidcapturesAggregatorInformation.
        :type: Ptsv2paymentsidcapturesAggregatorInformationSubMerchant
        """

        self._sub_merchant = sub_merchant

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidcapturesAggregatorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'offset': 'int',
        'limit': 'int',
        'page_results': 'int',
        'request_details': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]',
        'settlements': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]',
        'authorizations': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]',
        'fee_and_funding_details': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]',
        'others': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]',
        'settlement_statuses': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'page_results': 'pageResults',
        'request_details': 'requestDetails',
        'settlements': 'settlements',
        'authorizations': 'authorizations',
        'fee_and_funding_details': 'feeAndFundingDetails',
        'others': 'others',
        'settlement_statuses': 'settlementStatuses'
    }

    def __init__(self, offset=None, limit=None, page_results=None, request_details=None, settlements=None, authorizations=None, fee_and_funding_details=None, others=None, settlement_statuses=None):
        """
        ReportingV3PurchaseRefundDetailsGet200Response - a model defined in Swagger
        """

        self._offset = None
        self._limit = None
        self._page_results = None
        self._request_details = None
        self._settlements = None
        self._authorizations = None
        self._fee_and_funding_details = None
        self._others = None
        self._settlement_statuses = None

        if offset is not None:
          self.offset = offset
        if limit is not None:
          self.limit = limit
        if page_results is not None:
          self.page_results = page_results
        if request_details is not None:
          self.request_details = request_details
        if settlements is not None:
          self.settlements = settlements
        if authorizations is not None:
          self.authorizations = authorizations
        if fee_and_funding_details is not None:
          self.fee_and_funding_details = fee_and_funding_details
        if others is not None:
          self.others = others
        if settlement_statuses is not None:
          self.settlement_statuses = settlement_statuses

    @property
    def offset(self):
        """
        Gets the offset of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The offset of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param offset: The offset of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """
        Gets the limit of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The limit of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param limit: The limit of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._limit = limit

    @property
    def page_results(self):
        """
        Gets the page_results of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The page_results of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._page_results

    @page_results.setter
    def page_results(self, page_results):
        """
        Sets the page_results of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param page_results: The page_results of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._page_results = page_results

    @property
    def request_details(self):
        """
        Gets the request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Request Info values

        :return: The request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]
        """
        return self._request_details

    @request_details.setter
    def request_details(self, request_details):
        """
        Sets the request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Request Info values

        :param request_details: The request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]
        """

        self._request_details = request_details

    @property
    def settlements(self):
        """
        Gets the settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Info values

        :return: The settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]
        """
        return self._settlements

    @settlements.setter
    def settlements(self, settlements):
        """
        Sets the settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Info values

        :param settlements: The settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]
        """

        self._settlements = settlements

    @property
    def authorizations(self):
        """
        Gets the authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Authorization Info values

        :return: The authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]
        """
        return self._authorizations

    @authorizations.setter
    def authorizations(self, authorizations):
        """
        Sets the authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Authorization Info values

        :param authorizations: The authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]
        """

        self._authorizations = authorizations

    @property
    def fee_and_funding_details(self):
        """
        Gets the fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Fee Funding Info values

        :return: The fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]
        """
        return self._fee_and_funding_details

    @fee_and_funding_details.setter
    def fee_and_funding_details(self, fee_and_funding_details):
        """
        Sets the fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Fee Funding Info values

        :param fee_and_funding_details: The fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]
        """

        self._fee_and_funding_details = fee_and_funding_details

    @property
    def others(self):
        """
        Gets the others of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Other Info values

        :return: The others of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]
        """
        return self._others

    @others.setter
    def others(self, others):
        """
        Sets the others of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Other Info values

        :param others: The others of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]
        """

        self._others = others

    @property
    def settlement_statuses(self):
        """
        Gets the settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Status Info values

        :return: The settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]
        """
        return self._settlement_statuses

    @settlement_statuses.setter
    def settlement_statuses(self, settlement_statuses):
        """
        Sets the settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Status Info values

        :param settlement_statuses: The settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]
        """

        self._settlement_statuses = settlement_statuses

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'submit_time_utc': 'str',
        'merchant_id': 'str',
        'application_information': 'TssV2TransactionsPost201ResponseEmbeddedApplicationInformation',
        'buyer_information': 'TssV2TransactionsPost201ResponseEmbeddedBuyerInformation',
        'client_reference_information': 'TssV2TransactionsPost201ResponseEmbeddedClientReferenceInformation',
        'consumer_authentication_information': 'TssV2TransactionsPost201ResponseEmbeddedConsumerAuthenticationInformation',
        'device_information': 'TssV2TransactionsPost201ResponseEmbeddedDeviceInformation',
        'fraud_marking_information': 'TssV2TransactionsGet200ResponseFraudMarkingInformation',
        'merchant_defined_information': 'list[Ptsv2paymentsMerchantDefinedInformation]',
        'merchant_information': 'TssV2TransactionsPost201ResponseEmbeddedMerchantInformation',
        'order_information': 'TssV2TransactionsPost201ResponseEmbeddedOrderInformation',
        'payment_information': 'TssV2TransactionsPost201ResponseEmbeddedPaymentInformation',
        'processing_information': 'TssV2TransactionsPost201ResponseEmbeddedProcessingInformation',
        'processor_information': 'TssV2TransactionsPost201ResponseEmbeddedProcessorInformation',
        'point_of_sale_information': 'TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation',
        'risk_information': 'TssV2TransactionsPost201ResponseEmbeddedRiskInformation',
        'links': 'TssV2TransactionsPost201ResponseEmbeddedLinks'
    }

    attribute_map = {
        'id': 'id',
        'submit_time_utc': 'submitTimeUtc',
        'merchant_id': 'merchantId',
        'application_information': 'applicationInformation',
        'buyer_information': 'buyerInformation',
        'client_reference_information': 'clientReferenceInformation',
        'consumer_authentication_information': 'consumerAuthenticationInformation',
        'device_information': 'deviceInformation',
        'fraud_marking_information': 'fraudMarkingInformation',
        'merchant_defined_information': 'merchantDefinedInformation',
        'merchant_information': 'merchantInformation',
        'order_information': 'orderInformation',
        'payment_information': 'paymentInformation',
        'processing_information': 'processingInformation',
        'processor_information': 'processorInformation',
        'point_of_sale_information': 'pointOfSaleInformation',
        'risk_information': 'riskInformation',
        'links': '_links'
    }

    def __init__(self, id=None, submit_time_utc=None, merchant_id=None, application_information=None, buyer_information=None, client_reference_information=None, consumer_authentication_information=None, device_information=None, fraud_marking_information=None, merchant_defined_information=None, merchant_information=None, order_information=None, payment_information=None, processing_information=None, processor_information=None, point_of_sale_information=None, risk_information=None, links=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries - a model defined in Swagger
        """

        self._id = None
        self._submit_time_utc = None
        self._merchant_id = None
        self._application_information = None
        self._buyer_information = None
        self._client_reference_information = None
        self._consumer_authentication_information = None
        self._device_information = None
        self._fraud_marking_information = None
        self._merchant_defined_information = None
        self._merchant_information = None
        self._order_information = None
        self._payment_information = None
        self._processing_information = None
        self._processor_information = None
        self._point_of_sale_information = None
        self._risk_information = None
        self._links = None

        if id is not None:
          self.id = id
        if submit_time_utc is not None:
          self.submit_time_utc = submit_time_utc
        if merchant_id is not None:
          self.merchant_id = merchant_id
        if application_information is not None:
          self.application_information = application_information
        if buyer_information is not None:
          self.buyer_information = buyer_information
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if consumer_authentication_information is not None:
          self.consumer_authentication_information = consumer_authentication_information
        if device_information is not None:
          self.device_information = device_information
        if fraud_marking_information is not None:
          self.fraud_marking_information = fraud_marking_information
        if merchant_defined_information is not None:
          self.merchant_defined_information = merchant_defined_information
        if merchant_information is not None:
          self.merchant_information = merchant_information
        if order_information is not None:
          self.order_information = order_information
        if payment_information is not None:
          self.payment_information = payment_information
        if processing_information is not None:
          self.processing_information = processing_information
        if processor_information is not None:
          self.processor_information = processor_information
        if point_of_sale_information is not None:
          self.point_of_sale_information = point_of_sale_information
        if risk_information is not None:
          self.risk_information = risk_information
        if links is not None:
          self.links = links

    @property
    def id(self):
        """
        Gets the id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def submit_time_utc(self):
        """
        Gets the submit_time_utc of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :return: The submit_time_utc of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: str
        """
        return self._submit_time_utc

    @submit_time_utc.setter
    def submit_time_utc(self, submit_time_utc):
        """
        Sets the submit_time_utc of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :param submit_time_utc: The submit_time_utc of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: str
        """

        self._submit_time_utc = submit_time_utc

    @property
    def merchant_id(self):
        """
        Gets the merchant_id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        Your CyberSource merchant ID.

        :return: The merchant_id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: str
        """
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, merchant_id):
        """
        Sets the merchant_id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        Your CyberSource merchant ID.

        :param merchant_id: The merchant_id of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: str
        """

        self._merchant_id = merchant_id

    @property
    def application_information(self):
        """
        Gets the application_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The application_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedApplicationInformation
        """
        return self._application_information

    @application_information.setter
    def application_information(self, application_information):
        """
        Sets the application_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param application_information: The application_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedApplicationInformation
        """

        self._application_information = application_information

    @property
    def buyer_information(self):
        """
        Gets the buyer_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The buyer_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedBuyerInformation
        """
        return self._buyer_information

    @buyer_information.setter
    def buyer_information(self, buyer_information):
        """
        Sets the buyer_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param buyer_information: The buyer_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedBuyerInformation
        """

        self._buyer_information = buyer_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The client_reference_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param client_reference_information: The client_reference_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def consumer_authentication_information(self):
        """
        Gets the consumer_authentication_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The consumer_authentication_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedConsumerAuthenticationInformation
        """
        return self._consumer_authentication_information

    @consumer_authentication_information.setter
    def consumer_authentication_information(self, consumer_authentication_information):
        """
        Sets the consumer_authentication_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param consumer_authentication_information: The consumer_authentication_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedConsumerAuthenticationInformation
        """

        self._consumer_authentication_information = consumer_authentication_information

    @property
    def device_information(self):
        """
        Gets the device_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The device_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedDeviceInformation
        """
        return self._device_information

    @device_information.setter
    def device_information(self, device_information):
        """
        Sets the device_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param device_information: The device_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedDeviceInformation
        """

        self._device_information = device_information

    @property
    def fraud_marking_information(self):
        """
        Gets the fraud_marking_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The fraud_marking_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsGet200ResponseFraudMarkingInformation
        """
        return self._fraud_marking_information

    @fraud_marking_information.setter
    def fraud_marking_information(self, fraud_marking_information):
        """
        Sets the fraud_marking_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param fraud_marking_information: The fraud_marking_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsGet200ResponseFraudMarkingInformation
        """

        self._fraud_marking_information = fraud_marking_information

    @property
    def merchant_defined_information(self):
        """
        Gets the merchant_defined_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        The object containing the custom data that the merchant defines. 

        :return: The merchant_defined_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: list[Ptsv2paymentsMerchantDefinedInformation]
        """
        return self._merchant_defined_information

    @merchant_defined_information.setter
    def merchant_defined_information(self, merchant_defined_information):
        """
        Sets the merchant_defined_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        The object containing the custom data that the merchant defines. 

        :param merchant_defined_information: The merchant_defined_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: list[Ptsv2paymentsMerchantDefinedInformation]
        """

        self._merchant_defined_information = merchant_defined_information

    @property
    def merchant_information(self):
        """
        Gets the merchant_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The merchant_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedMerchantInformation
        """
        return self._merchant_information

    @merchant_information.setter
    def merchant_information(self, merchant_information):
        """
        Sets the merchant_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param merchant_information: The merchant_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedMerchantInformation
        """

        self._merchant_information = merchant_information

    @property
    def order_information(self):
        """
        Gets the order_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The order_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param order_information: The order_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedOrderInformation
        """

        self._order_information = order_information

    @property
    def payment_information(self):
        """
        Gets the payment_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The payment_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedPaymentInformation
        """
        return self._payment_information

    @payment_information.setter
    def payment_information(self, payment_information):
        """
        Sets the payment_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param payment_information: The payment_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedPaymentInformation
        """

        self._payment_information = payment_information

    @property
    def processing_information(self):
        """
        Gets the processing_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The processing_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedProcessingInformation
        """
        return self._processing_information

    @processing_information.setter
    def processing_information(self, processing_information):
        """
        Sets the processing_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param processing_information: The processing_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedProcessingInformation
        """

        self._processing_information = processing_information

    @property
    def processor_information(self):
        """
        Gets the processor_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The processor_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedProcessorInformation
        """
        return self._processor_information

    @processor_information.setter
    def processor_information(self, processor_information):
        """
        Sets the processor_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param processor_information: The processor_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedProcessorInformation
        """

        self._processor_information = processor_information

    @property
    def point_of_sale_information(self):
        """
        Gets the point_of_sale_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The point_of_sale_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation
        """
        return self._point_of_sale_information

    @point_of_sale_information.setter
    def point_of_sale_information(self, point_of_sale_information):
        """
        Sets the point_of_sale_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param point_of_sale_information: The point_of_sale_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation
        """

        self._point_of_sale_information = point_of_sale_information

    @property
    def risk_information(self):
        """
        Gets the risk_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The risk_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedRiskInformation
        """
        return self._risk_information

    @risk_information.setter
    def risk_information(self, risk_information):
        """
        Sets the risk_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param risk_information: The risk_information of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedRiskInformation
        """

        self._risk_information = risk_information

    @property
    def links(self):
        """
        Gets the links of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :return: The links of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.

        :param links: The links of this TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries.
        :type: TssV2TransactionsPost201ResponseEmbeddedLinks
        """

        self._links = links

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
